==> haskell-logging-facade-0.3.0-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logging-facade
version: 0.3.0
id: logging-facade-0.3.0-4gnXP6GGYSQATy8alz82JA
key: logging-facade-0.3.0-4gnXP6GGYSQATy8alz82JA
license: MIT
copyright: (c) 2014-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/logging-facade#readme
synopsis: Simple logging abstraction that allows multiple back-ends
description:
    Simple logging abstraction that allows multiple back-ends
category: System
abi: a63f83b1603648815ac3f8fd3dc11596
exposed: True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types
hidden-modules: Paths_logging_facade
import-dirs: /usr/lib/ghc-8.4.3/site-local/logging-facade-0.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/logging-facade-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/logging-facade-0.3.0
hs-libraries: HSlogging-facade-0.3.0-4gnXP6GGYSQATy8alz82JA
depends:
    base-4.11.1.0 call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
    transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=c76ca250c7cf6b5c2ee744c15760c93f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock
haddock-html: /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logging-facade-0.3.0-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logging-facade
version: 0.3.0
id: logging-facade-0.3.0-K9MLU81SoYhEF8ffzrGA0k
key: logging-facade-0.3.0-K9MLU81SoYhEF8ffzrGA0k
license: MIT
copyright: (c) 2014-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/logging-facade#readme
synopsis: Simple logging abstraction that allows multiple back-ends
description:
    Simple logging abstraction that allows multiple back-ends
category: System
abi: 4eeb60f43e53ed582dc6f673f5eae7cf
exposed: True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types
hidden-modules: Paths_logging_facade
import-dirs: /usr/lib/ghc-8.4.3/site-local/logging-facade-0.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/logging-facade-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/logging-facade-0.3.0
hs-libraries: HSlogging-facade-0.3.0-K9MLU81SoYhEF8ffzrGA0k
depends:
    base-4.11.1.0 call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
    transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=c76ca250c7cf6b5c2ee744c15760c93f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock
haddock-html: /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
